@@ -1,6 +1,6 @@
 #! /bin/bash -e
 # -----------------------------------------------------------------------------
-# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-20 Bradley M. Bell
+# CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 #
 # CppAD is distributed under the terms of the
 #              Eclipse Public License Version 2.0.
@@ -72,6 +72,24 @@ echo_eval() {
 web_page='https://github.com/CSCsw/ColPack.git'
 cppad_dir=`pwd`
 # -----------------------------------------------------------------------------
+# libtoolize is brain dead and puts these files in cppad_dir
+for file in ltmain.sh test-driver
+do
+    if [ -e $cppad_dir/$file ]
+    then
+        echo "get_colpack.sh: did not expect $file in $cppad_dir"
+        exit 1
+    fi
+done
+# -----------------------------------------------------------------------------
+# n_job
+if which nproc > /dev/null
+then
+    n_job=$(nproc)
+else
+    n_job=$(sysctl -n hw.ncpu)
+fi
+# ----------------------------------------------------------------------------
 # prefix
 eval `grep '^prefix=' bin/get_optional.sh`
 if [[ "$prefix" =~ ^[^/] ]]
@@ -86,7 +104,7 @@ if [ -e "$configured_flag" ]
 then
     echo "Skipping configuration because $configured_flag exits"
     echo_eval cd external/$package.git
-    echo_eval make install
+    echo_eval make -j $n_job install
     echo "get_$package.sh: OK"
     exit 0
 fi
@@ -133,6 +151,17 @@ echo_eval ./configure \
     $lib_type
 #
 echo_eval touch $cppad_dir/$configured_flag
-echo_eval make install
+echo_eval make -j $n_job install
+# -----------------------------------------------------------------------------
+# libtoolize is brain dead and puts these files in cppad_dir
+for file in ltmain.sh test-driver
+do
+    if [ ! -e $cppad_dir/$file ]
+    then
+        echo "get_colpack.sh: expected libtooize to create $cppad_dir/$file"
+        exit 1
+    fi
+    rm $cppad_dir/$file
+done
 # -----------------------------------------------------------------------------
 echo "get_$package: OK"
