@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -77,7 +77,7 @@ Only zero order forward mode is implements for the
 $code atomic_user$$ class.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN USER C++%// END USER C++%
 1%$$
 
@@ -101,13 +101,13 @@ public:
     { }
 private:
     // forward mode routine called by CppAD
-    virtual bool forward(
+    bool forward(
         size_t                   p   ,
         size_t                   q   ,
         const vector<bool>&      vu  ,
         vector<bool>&            vy  ,
         const vector<double>&    tu  ,
-        vector<double>&          ty  )
+        vector<double>&          ty  ) override
     {
 # ifndef NDEBUG
         size_t n = tu.size() / (q + 1);
@@ -158,7 +158,7 @@ This source code defines the common variables that are used by
 the $codei%multi_atomic_two_%name%$$ functions.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN COMMON C++%// END COMMON C++%
 1%$$
 
@@ -239,7 +239,7 @@ If it is false,
 $code multi_atomic_two_setup$$ detected an error.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN SETUP C++%// END SETUP C++%
 1%$$
 
@@ -317,7 +317,7 @@ $head Purpose$$
 This routine does the computation for one thread.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN WORKER C++%// END WORKER C++%
 1%$$
 
@@ -383,7 +383,7 @@ If it is false,
 $code multi_atomic_two_takedown$$ detected an error.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN TAKEDOWN C++%// END TAKEDOWN C++%
 1%$$
 
@@ -478,7 +478,7 @@ If it is false,
 $code multi_atomic_two_run$$ detected an error.
 
 $head Source$$
-$srcfile%example/multi_thread/multi_atomic_two.cpp%0
+$srcthisfile%0
     %// BEGIN RUN C++%// END RUN C++%
 1%$$
 
