@@ -1,7 +1,7 @@
 # ifndef CPPAD_LOCAL_SWEEP_DYNAMIC_HPP
 # define CPPAD_LOCAL_SWEEP_DYNAMIC_HPP
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-19 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -121,7 +121,7 @@ void dynamic(
     // used to hold the first two parameter arguments
     const Base* par[2];
     for(size_t j = 0; j < 2; ++j)
-        par[j] = CPPAD_NULL;
+        par[j] = nullptr;
     //
     // Initialize index in dyn_par_arg
     size_t i_arg = 0;
@@ -247,7 +247,6 @@ void dynamic(
             all_par_vec[i_par] = tanh( *par[0] );
             break;
 
-# if CPPAD_USE_CPLUSPLUS_2011
             // ---------------------------------------------------------------
             // asinh
             case asinh_dyn:
@@ -290,7 +289,6 @@ void dynamic(
             CPPAD_ASSERT_UNKNOWN( n_arg == 1 );
             all_par_vec[i_par] = log1p( *par[0] );
             break;
-# endif
             // ---------------------------------------------------------------
             // abs
             case abs_dyn:
@@ -316,6 +314,12 @@ void dynamic(
             all_par_vec[i_par] = *par[0] * *par[1];
             break;
 
+            // neg
+            case neg_dyn:
+            CPPAD_ASSERT_UNKNOWN( n_arg == 1 );
+            all_par_vec[i_par] = - *par[0];
+            break;
+
             // pow
             case pow_dyn:
             CPPAD_ASSERT_UNKNOWN( n_arg == 2 );
@@ -455,7 +459,7 @@ void dynamic(
                 bool         set_null = false;
                 size_t       type     = 0;          // set to avoid warning
                 std::string name;
-                void*        v_ptr    = CPPAD_NULL; // set to avoid warning
+                void*        v_ptr    = nullptr; // set to avoid warning
                 atomic_index<RecBase>(
                     set_null, atom_index, type, &name, v_ptr
                 );
