@@ -1,5 +1,5 @@
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-18 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-21 Bradley M. Bell
 
 CppAD is distributed under the terms of the
              Eclipse Public License Version 2.0.
@@ -28,10 +28,10 @@ $head Purpose$$
 Consider the case where an inner function is used repeatedly in the
 definition of an outer function.
 In this case, it may reduce the number of variables
-$cref/size_var/seq_property/size_var/$$,
+$cref/size_var/fun_property/size_var/$$,
 and hence the required memory.
 
-$srcfile%test_more/deprecated/old_usead_2.cpp%0%// BEGIN C++%// END C++%1%$$
+$srcthisfile%0%// BEGIN C++%// END C++%1%$$
 
 $end
 */
@@ -81,7 +81,7 @@ namespace { // Begin empty namespace
     }
     void destroy_r(void)
     {   delete r_ptr_;
-        r_ptr_ = CPPAD_NULL;
+        r_ptr_ = nullptr;
     }
 
     // ----------------------------------------------------------------------
